@@ -7,7 +7,6 @@ import enum
 
 class PathValues(str, enum.Enum):
     _ = "/"
-    SNAP_TRADE_ACCEPT_DISCLAIMER = "/snapTrade/acceptDisclaimer"
     SNAP_TRADE_LIST_USERS = "/snapTrade/listUsers"
     SNAP_TRADE_REGISTER_USER = "/snapTrade/registerUser"
     SNAP_TRADE_DELETE_USER = "/snapTrade/deleteUser"
@@ -57,7 +56,6 @@ class PathValues(str, enum.Enum):
     PORTFOLIO_GROUPS_PORTFOLIO_GROUP_ID_EXCLUDEDASSETS_SYMBOL_ID = "/portfolioGroups/{portfolioGroupId}/excludedassets/{symbolId}"
     PORTFOLIO_GROUPS_PORTFOLIO_GROUP_ID_IMPORT = "/portfolioGroups/{portfolioGroupId}/import"
     PORTFOLIO_GROUPS_PORTFOLIO_GROUP_ID_INFO = "/portfolioGroups/{portfolioGroupId}/info"
-    PORTFOLIO_GROUPS_PORTFOLIO_GROUP_ID_POSITIONS = "/portfolioGroups/{portfolioGroupId}/positions"
     PORTFOLIO_GROUPS_PORTFOLIO_GROUP_ID_SETTINGS = "/portfolioGroups/{portfolioGroupId}/settings"
     PORTFOLIO_GROUPS_PORTFOLIO_GROUP_ID_SYMBOLS = "/portfolioGroups/{portfolioGroupId}/symbols"
     PORTFOLIO_GROUPS_PORTFOLIO_GROUP_ID_TARGETS = "/portfolioGroups/{portfolioGroupId}/targets"
